#
# DigitalCommon.py - Common Digital Display Classes for adesklets
#                    Very lightweight, uses NO external images files.
#
#  Copyright(C) 2008, Angelo arrifano <miknix@gmail.com>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

import adesklets

#
# Class NumDisplay
# Digital Numeric Display
#
class NumDisplay:
	imgDig = []	

	def __init__(self, xPos = 0, yPos = 0, \
	        onColor = [255, 0, 0, 255], offColor = [77, 0, 0, 255]):
		
		self.onColor = onColor
		self.offColor = offColor
		self.xPos = xPos
		self.yPos = yPos

		# Build images from segment information
		# only one time.
		if not self.imgDig:
			segData = [
				[1,1,1,0,1,1,1], \
				[0,0,1,0,0,1,0], \
				[1,0,1,1,1,0,1], \
				[1,0,1,1,0,1,1], \
				[0,1,1,1,0,1,0], \
				[1,1,0,1,0,1,1], \
				[1,1,0,1,1,1,1], \
				[1,0,1,0,0,1,0], \
				[1,1,1,1,1,1,1], \
				[1,1,1,1,0,1,0]]
	
			for i in range(0, 10):
				self.imgDig.append(adesklets.create_image_using_data(7, 13, \
			                             self._rebuild_digits(segData[i])))
	
	# Hmm.. Were should I call this?
	# I don't mind to leak memory when I exit my session,
	# do you?
	def __del__(self):
		for img in self.imgDig:
			adesklets.free_image(img)

	# Create pixmaps from segment information
	def _rebuild_digits(self, segData):
		pixmap = []
		
		def get_color(v):
			if (v):
				c = self.onColor
			else:
				c = self.offColor
			return c

		def print_hz(c):
			c = get_color(c)
			pixmap.extend([0, 0, 0, 255])
			for i in range(0,5):
				pixmap.extend(c)
			pixmap.extend([0, 0, 0, 255])

		def print_vt(c1, c2):
			c1 = get_color(c1)
			c2 = get_color(c2)
			for j in range(0,5):
				pixmap.extend(c1)
				for i in range(0,5):
					pixmap.extend([0, 0, 0, 255])
				pixmap.extend(c2)

		print_hz(segData[0])
		print_vt(segData[1], segData[2])
		print_hz(segData[3])
		print_vt(segData[4], segData[5])
		print_hz(segData[6])
		return pixmap

	# Set display ON color
	def set_color_on(self, c):
		self.onColor = c

	# Set display OFF color
	def set_color_off(self, c):
		self.offColor = c

	# Set display position
	def set_pos(self, x, y):
		self.xPos = x
		self.yPos = y

	# Draw digits
	# snum - Numeric string
	def draw(self, snum):
		adesklets.context_set_blend(False)
		for i in range(0, len(snum)):
			adesklets.blend_image_onto_image(self.imgDig[int(snum[i])], 1, \
		                               0, 0, 7, 13, \
		                               9*i + self.xPos, self.yPos, 7, 13)
	
#
# Class WDDisplay
# Digital Watchdog Display
#
class WDDisplay:
	def __init__(self, xPos = 0, yPos = 0, \
	            onColor = [255, 0, 0, 255], offColor = [77, 0, 0, 255]):
		
		self.onColor = onColor
		self.offColor = offColor
		self.xPos = xPos
		self.yPos = yPos
		self.state = 0

	# Set display ON color
	def set_color_on(self, c):
		self.onColor = c

	# Set display OFF color
	def set_color_off(self, c):
		self.offColor = c

	# Set display position
	def set_pos(self, x, y):
		self.xPos = x
		self.yPos = y

	# Ping display
	# showing that this desklet is still working
	def ping(self):
		adesklets.context_set_blend(False)
		for i in range(0,3):
			if (self.state % 3 == i):
				adesklets.context_set_color(self.onColor[0], self.onColor[1],
				                            self.onColor[2], self.onColor[3])
			else:
				adesklets.context_set_color(self.offColor[0], self.offColor[1],
				                            self.offColor[2], self.offColor[3])
			adesklets.image_fill_rectangle(i*3 + self.xPos, self.yPos, 2, 2)
		self.state = self.state + 1
